/***************************************************************************
    smb4kbookmark.cpp  - A bookmark container.
                             -------------------
    begin                : Feb 04 2004
    copyright            : (C) 2004 by Franck Babin
    email                : babinfranck@yahoo.ca
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

 //Application includes
#include "smb4kbookmark.h"

Smb4KBookmark::Smb4KBookmark( const QString &share, const QString &type ) 
: m_share(share), m_type( type )
{
    //FIXME should throw an exception if one of the param is empty
}

Smb4KBookmark::~Smb4KBookmark(){}



QString Smb4KBookmark::getShare() const
{
  return m_share;
}


QString Smb4KBookmark::getType() const
{
  return m_type;
}

